#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-CLbEk2YsfnFYwCxvuWSoO
key:                  xml-conduit-1.9.1.4-CLbEk2YsfnFYwCxvuWSoO
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  12ec73f87709d63c5b76a9c16a88c398
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-CLbEk2YsfnFYwCxvuWSoO
depends:
    attoparsec-0.14.4-JfqiEkfNFnE8n0O4G6WZl6 base-4.18.2.1
    blaze-html-0.9.2.0-EgbbWPmo3205UQl3AObEBN
    blaze-markup-0.8.3.0-95wdhLC99M6I30rZ5XrQvr bytestring-0.11.5.3
    conduit-1.3.6.1-GLye9k05ayiLdzpPDhJU0K
    conduit-extra-1.3.8-C49LxeOQ7VlKv4GFzxOpy7 containers-0.6.7
    data-default-0.7.1.3-CRQVneoi5B7He0Tx6HSYSU deepseq-1.4.8.1
    resourcet-1.2.6-2ZRVpZAaCnB5eaGpQGOamD text-2.0.2
    transformers-0.6.1.0 xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

